RuntimeKit

Trait RuntimeKit 

pub trait RuntimeKit:
    Executor
    + Reactor
    + Debug { }
Marker supertrait for types that satisfy all requirements of a full async runtime.

A type implements RuntimeKit when it is both an Executor (can spawn and block on futures) and a Reactor (can perform async I/O and timers) and is Debug. This trait has no methods of its own; it exists purely as a convenient single bound used by Runtime and RuntimeParts.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors