pub trait TaskImpl:
Future
+ Send
+ Unpin
+ 'static {
// Provided methods
fn cancel<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Option<<Self as Future>::Output>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait { ... }
fn detach(&mut self)
where Self: Sized { ... }
}Expand description
A common interface to wait for a Task completion, let it run in the background or cancel it.
Provided Methods
Sourcefn cancel<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Option<<Self as Future>::Output>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn cancel<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Option<<Self as Future>::Output>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Cancels the task and waits for it to stop running.
Returns the task’s output if it was completed just before it got canceled, or None if it didn’t complete.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".