A collection of utilities to deal with IO, futures and runtimes
Structs
- DummyIO
- A dummy struct implementing Async IO traits
- Dummy
Stream - A dummy struct implementing Stream
- IOHandle
- A synchronous IO handle
- Join
- Future returned by
join. - Read
Half - The read half produced by
split. - Runtime
Parts - A
RuntimeKitcomposed of independentExecutorandReactorinstances. - Socket
Addrs - Wrapper to impl AsyncToSocketAddrs from an IntoIterator<Item = SocketAddr>
- Socket
Addrs From IpAddrs - Iterator for SocketAddr computed from IpAddr + port
- Socket
Addrs Resolver - Wrapper to perform blocking name resolution on top of an async runtime
- Task
- A wrapper around implementation-specific tasks that implement the TaskImpl trait
- TryJoin
- Future returned by
try_join. - Write
Half - The write half produced by
split.
Traits
- Task
Impl - A common interface to wait for a Task completion, let it run in the background or cancel it.
Functions
- block_
on_ tokio - Block on the given future in a tokio context, creating a new one if required
- inside_
tokio - Check whether we’re in a tokio context or not
- join
- Drive two futures concurrently, returning both outputs once both complete.
- simple_
block_ on - Simple naive block_on implementation for noop runtime
- split
- Split a bidirectional stream into independently-owned read and write halves.
- try_
join - Drive two fallible futures concurrently, short-circuiting on the first error.